==> trafficserver_5.3.0.orig.tar.bz2: trafficserver-5.3.0/plugins/experimental/balancer/roundrobin.cc <==
/** @file
 *
 *  A brief file description
 *
 *  @section license License
 *
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

#include "balancer.h"
#include <stdlib.h>
#include <string.h>
#include <map>
#include <string>
#include <vector>

namespace
{
struct RoundRobinBalancer : public BalancerInstance {
  RoundRobinBalancer() : targets(), next(0) {}

  void
  push_target(const BalancerTarget &target)
  {
    this->targets.push_back(target);
  }

  const BalancerTarget &
  balance(TSHttpTxn, TSRemapRequestInfo *)
  {
    return this->targets[++next % this->targets.size()];
  }

  std::vector<BalancerTarget> targets;
  unsigned next;
};

} // namespace

BalancerInstance *
MakeRoundRobinBalancer(const char *options)
{
  RoundRobinBalancer *hash = new RoundRobinBalancer();
  char *opt;
  char *tmp;

  TSDebug("balancer", "making round robin balancer with options '%s'", options);

  if (options) {
    options = tmp = strdup(options);
    while ((opt = strsep(&tmp, ",")) != NULL) {
      TSError("balancer: ignoring invalid round robin field '%s'", opt);
    }

    free((void *)options);
  }

  return hash;
}

==> trafficserver_6.1.1.orig.tar.bz2: trafficserver-6.1.1/plugins/experimental/balancer/roundrobin.cc <==
/** @file
 *
 *  A brief file description
 *
 *  @section license License
 *
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

#include "balancer.h"
#include <stdlib.h>
#include <string.h>
#include <map>
#include <string>
#include <vector>

namespace
{
struct RoundRobinBalancer : public BalancerInstance {
  RoundRobinBalancer() : targets(), next(0) {}

  void
  push_target(const BalancerTarget &target)
  {
    this->targets.push_back(target);
  }

  const BalancerTarget &
  balance(TSHttpTxn, TSRemapRequestInfo *)
  {
    return this->targets[++next % this->targets.size()];
  }

  std::vector<BalancerTarget> targets;
  unsigned next;
};

} // namespace

BalancerInstance *
MakeRoundRobinBalancer(const char *options)
{
  RoundRobinBalancer *hash = new RoundRobinBalancer();
  char *opt;
  char *tmp;

  TSDebug("balancer", "making round robin balancer with options '%s'", options);

  if (options) {
    options = tmp = strdup(options);
    while ((opt = strsep(&tmp, ",")) != NULL) {
      TSError("[balancer] Ignoring invalid round robin field '%s'", opt);
    }

    free((void *)options);
  }

  return hash;
}
